import {validURL} from "@/utils/validate";

/**
 * 图片转圆形图片
 * @param {图片地址} imageSrc
 */
export function circularPicture(imageSrc: string) {
  const fun = (resolve: any) => {
    const canvas = document.createElement("canvas");
    const contex = canvas.getContext("2d") as CanvasRenderingContext2D;
    const img = new Image();
    img.crossOrigin = "";

    img.onload = () => {
      let center = {
        x: img.width / 2,
        y: img.height / 2.5,
      };
      let diameter = img.width;
      canvas.width = diameter;
      canvas.height = diameter;
      contex.clearRect(0, 0, diameter, diameter);
      contex.save();
      contex.beginPath();
      let radius = img.width / 2;
      contex.arc(radius, radius, radius, 0, 2 * Math.PI); //画出圆
      contex.clip(); //裁剪上面的圆形
      contex.drawImage(
        img,
        center.x - radius,
        center.y - radius,
        diameter,
        diameter,
        0,
        0,
        diameter,
        diameter
      ); // 在刚刚裁剪的园上画图
      contex.restore(); // 还原状态
      resolve(canvas.toDataURL("image/png", 1));
    };
    img.src = imageSrc;
  };
  return new Promise(fun);
}

/**
 * 查询图片地址
 * @param imageSrc 图片地址
 * @param baseApi 后台基础路径
 * @returns {*|string}
 */
export function getImageSrc(imageSrc: string) {
  const baseApi = process.env.VUE_APP_BASE_API as string

  if (!imageSrc) {
    return imageSrc
  } else if (validURL(imageSrc)) {
    return imageSrc
  } else if (imageSrc.indexOf(baseApi) === 0) {
    return imageSrc
  } else if (imageSrc.startsWith('/static')) {
    return imageSrc
  } else {
    return baseApi + imageSrc
  }
}
