import {useRouter} from 'vue-router'

const router = useRouter()

export const getImgUrl = (name: string) => {
  return new URL(name, import.meta.url).href
}

/**
 * 跳转页面
 * @param path    路由地址
 * @param query   参数
 * @param isBlank 是否新页面打开
 */
export function jumpPage(path: string, query: any = null, isBlank = false) {
  if (path) {
    if (!isBlank) {
      router.push({path, query})
    } else {
      if (path.indexOf('http') !== -1) {
        window.open(path, '_blank')
      } else {
        let routeUrl = router.resolve({path, query})
        window.open(routeUrl.href, '_blank')
      }
    }
  }
}


/**
 * Merges two objects, giving the last one precedence
 * @param {Object} target
 * @param {(Object|Array)} source
 * @returns {Object}
 */
export function objectMerge(target: any, source: any) {
  if (typeof target !== 'object') {
    target = {}
  }
  if (Array.isArray(source)) {
    return source.slice()
  }
  Object.keys(source).forEach(property => {
    const sourceProperty = source[property]
    if (typeof sourceProperty === 'object' && sourceProperty !== null) {
      target[property] = objectMerge(target[property], sourceProperty)
    } else {
      target[property] = sourceProperty
    }
  })
  return target
}
