/**
 * 通用js方法封装处理
 * Copyright (c) 2019 ruoyi
 */

// 日期格式化
export function parseTime(time: any, pattern: string) {
  if (arguments.length === 0 || !time) {
    return null;
  }
  const format = pattern || "{y}-{m}-{d} {h}:{i}:{s}";
  let date;
  if (typeof time === "object") {
    date = time;
  } else {
    if (typeof time === "string" && /^[0-9]+$/.test(time)) {
      time = parseInt(time);
    } else if (typeof time === "string") {
      time = time
        .replace(new RegExp(/-/gm), "/")
        .replace("T", " ")
        .replace(new RegExp(/\.[\d]{3}/gm), "");
    }
    if (typeof time === "number" && time.toString().length === 10) {
      time = time * 1000;
    }
    date = new Date(time);
  }
  const formatObj: { [key: string]: any } = {
    y: date.getFullYear(),
    m: date.getMonth() + 1,
    d: date.getDate(),
    h: date.getHours(),
    i: date.getMinutes(),
    s: date.getSeconds(),
    a: date.getDay(),
  };
  const time_str = format.replace(/{(y|m|d|h|i|s|a)+}/g, (result, key) => {
    let value = formatObj[key];
    // Note: getDay() returns 0 on Sunday
    if (key === "a") {
      return ["日", "一", "二", "三", "四", "五", "六"][value];
    }
    if (result.length > 0 && value < 10) {
      value = "0" + value;
    }
    return value || 0;
  });
  return time_str;
}

// 字符串格式化(%s )
export function sprintf(str: string) {
  var args = arguments,
    flag = true,
    i = 1;
  str = str.replace(/%s/g, function () {
    var arg = args[i++];
    if (typeof arg === "undefined") {
      flag = false;
      return "";
    }
    return arg;
  });
  return flag ? str : "";
}

// 转换字符串，undefined,null等转化为""
export function praseStrEmpty(str: any) {
  if (!str || str == "undefined" || str == "null") {
    return "";
  }
  return str;
}

/**
 * 构造树型结构数据
 * @param {*} data 数据源
 * @param {*} id id字段 默认 'id'
 * @param {*} parentId 父节点字段 默认 'parentId'
 * @param {*} children 孩子节点字段 默认 'children'
 */
export function handleTree(data: any[], id: string, parentId: string, children: string) {
  let config = {
    id: id || "id",
    parentId: parentId || "parentId",
    childrenList: children || "children",
  };

  var childrenListMap: { [key: string]: any } = {};
  var nodeIds: { [key: string]: any } = {};
  var tree = [];

  for (let d of data) {
    let parentId = d[config.parentId];
    if (childrenListMap[parentId] == null) {
      childrenListMap[parentId] = [];
    }
    nodeIds[d[config.id]] = d;
    childrenListMap[parentId].push(d);
  }

  for (let d of data) {
    let parentId = d[config.parentId];
    if (nodeIds[parentId] == null) {
      tree.push(d);
    }
  }

  for (let t of tree) {
    adaptToChildrenList(t);
  }

  function adaptToChildrenList(o: any) {
    if (childrenListMap[o[config.id]] !== null) {
      o[config.childrenList] = childrenListMap[o[config.id]];
    }
    if (o[config.childrenList]) {
      for (let c of o[config.childrenList]) {
        adaptToChildrenList(c);
      }
    }
  }

  return tree;
}

export function treeToList(treeList: any[]) {
  let list: any[] = [];

  function traverse(node: { [key: string]: any }) {
    if (node) {
      list.push(node); // 将节点的值新建到列表中
      if (node.children) {
        for (let child of node.children) {
          traverse(child); // 递归遍历子节点
        }
      }
    }
  }

  treeList.forEach((tree) => traverse(tree))
  return list;
}

export function createTree(list: any[], value: any, parentId: string, id: string) {
  let tree = [];
  for (let num = 0; num < list.length; num++) {
    let data = list[num];
    if (data[parentId] === value) {
      let children = createTree(list, data[id], parentId, id);
      if (children && children.length > 0) {
        data["children"] = children;
      }
      tree.push(data);
    }
  }
  return tree;
}

export function copyObj(obj: object) {
  let newObjStr = JSON.stringify(obj);
  return JSON.parse(newObjStr);
}

/**
 * * 生成一个不重复的ID
 * @param { Number } randomLength
 */
export const getUUID = (randomLength = 10) => {
  return Number(
    Math.random().toString().substr(2, randomLength) + Date.now()
  ).toString(36);
};

export function dateFYMDHM(val: string) {
  if (val) {
    return (
      val.substr(0, 4) +
      "-" +
      val.substr(4, 2) +
      "-" +
      val.substr(6, 2) +
      " " +
      val.substr(8, 2) +
      ":" +
      val.substr(10, 2)
    );
  }
  return "";
}

/**
 * 列表筛重
 * @param list  列表
 * @param key   筛选字段
 * @returns {Set<any>[]|*|*[]}
 */
export function listFilterDuplicateData(list: any[], key: string) {
  if (!list || list.length === 0) {
    return list
  }
  if (!key) {
    return Array.from(new Set(list))
  }

  const fdd = new Set(list.map(i => i[key]))

  let retList: any[] = []
  list.forEach(i => {
    let param = i[key];
    if (fdd.has(param)) {
      retList.push(i);
      fdd.delete(param)
    }
  })

  return retList
}

export function getObjectSize(obj: object) {
  let count = 0
  for (let key in obj)
    count++
  return count
}

// a 数组是否包含 b 数组的值
export function isHasByOtherArray(a = [], b = []) {
  for (let i in a) {
    for (let j in b) {
      if (a[i] == b[j]) {
        return true
      }
    }
  }
  return false
}
